ledger.MatchRule (Match rule) — amici1

# `ledger.MatchRule` (Match rule)

MatchRule(id, account, journal)

Master tables : ledger.MatchRules (Match rules)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Account (account) : See `<django.db.models.fields.related.ForeignKey: account>`.

- Journal (journal) : See `<django.db.models.fields.related.ForeignKey: journal>`.

- Name (name_column) : See `lino_xl.lib.ledger.models.MatchRule.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.ledger.models.MatchRule.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.ledger.models.MatchRule.overview`.

Referenced from

## Database fields

Internal name | Verbose name | Help text
id | ID |
account | Account |
journal | Journal |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |